using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Windows.Forms;
using Infragistics.Win.UltraWinGrid;
using Infragistics.Win;
using System.Diagnostics;

namespace MemDataTable_CS
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();            
        }        

        private DataTable dt1;

        private void Form1_Load(object sender, System.EventArgs e)
        {            
            // Set grid's DataSource
            dt1 = DummyDataCreator.GetData(10);
            dt1.TableName = "Band 0";
            this.ultraGrid1.SetDataBinding(dt1, null);

            this.ultraGrid1.CreationFilter = new CardViewColumnChooserCreationFilter();
        }

        private void ultraGrid1_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            UltraGridLayout layout = e.Layout;
            UltraGridBand band = layout.Bands[0];
            UltraGridOverride ov = layout.Override;

            band.CardView = true;
        }
    }

    public class CardViewColumnChooserCreationFilter : IUIElementCreationFilter
    {
        void IUIElementCreationFilter.AfterCreateChildElements(UIElement parent)
        {
            var cardAreaScrollRegionUIElement = parent as CardAreaScrollRegionUIElement;
            if (null == cardAreaScrollRegionUIElement)
                return;

            ColumnChooserButtonUIElement columnChooserButtonUIElement;

            columnChooserButtonUIElement = parent.GetDescendant(typeof(ColumnChooserButtonUIElement)) as ColumnChooserButtonUIElement;
            if (null == columnChooserButtonUIElement)
            {
                columnChooserButtonUIElement = new ColumnChooserButtonUIElement(cardAreaScrollRegionUIElement);
                parent.ChildElements.Add(columnChooserButtonUIElement);
            }


            // This is making the assumption that the first RowUIElement in the left-most card, which
            // seems to be true right now. 
            // Since the order of the UIElements is arbitrary, it's possible (although unlikely) that this
            // might not be true in some future version of the grid. So a more reliable way to do this 
            // would be to get all of the RowUIElements and then sort them by their horizontal positions. 
            var rowUIElement = parent.GetDescendant(typeof(RowUIElement));
            var cardCaptionUIElement  = rowUIElement != null 
                ? rowUIElement.GetDescendant(typeof(CardCaptionUIElement))
                : null;

            int x;
            int y;
            int extent;
            if (null != cardCaptionUIElement)
            {
                extent = cardCaptionUIElement.Rect.Height;
                x = cardCaptionUIElement.Rect.Left - extent;
                y = cardCaptionUIElement.Rect.Top;
            }
            else
            {
                // Make up some fallback values that look okay. 
                x = 56;
                y = 24;
                extent = 23;
            }

            var columnChooserButtonUIElementRect = new Rectangle(
                x,
                y,
                extent,
                extent);

            columnChooserButtonUIElement.Rect = columnChooserButtonUIElementRect;
        }

        bool IUIElementCreationFilter.BeforeCreateChildElements(UIElement parent)
        {
            // Do nothing
            return false;
        }
    }

}